# -*- coding: utf-8 -*-
# Generated by Django 1.9.9 on 2016-11-05 00:47
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('django_simple_files', '0002_files_enabled'),
    ]

    operations = [
        migrations.AddField(
            model_name='files',
            name='file_name',
            field=models.CharField(default='file', max_length=255, verbose_name='文件名'),
            preserve_default=False,
        ),
        migrations.AlterField(
            model_name='files',
            name='file_hash',
            field=models.CharField(max_length=40, verbose_name='文件hash'),
        ),
        migrations.AlterField(
            model_name='files',
            name='file_uri',
            field=models.FileField(max_length=255, upload_to='upload/%Y%m%d', verbose_name='文件'),
        ),
    ]
